==> announcementcenter-v7.0.1-frama.tar.gz: announcementcenter/l10n/lv.js <==
OC.L10N.register(
    "announcementcenter",
    {
    "You posted an announcement" : "Tu izliki paziņojumu",
    "{actor} posted an announcement" : "{actor} izlika paziņojumu",
    "An <strong>announcement</strong> is posted by an administrator" : "Šis <strong>paziņojums</strong> ir no administratora",
    "The subject is too long or empty" : "Temats ir par garu vai arī tukšs",
    "Announcements" : "Paziņojumi",
    "Read more" : "Lasīt vairāk",
    "{user} announced “{announcement}”" : "{user} paziņots “{announcement}”",
    "Announcement center" : "Paziņojumu centrs",
    "These groups will be able to post announcements." : "Šīs grupas varēs ievietot paziņojumus.",
    "Create activities by default" : "Izveidot darbības pēc noklusējuma",
    "Create notifications by default" : "Izveidot ziņojumus pēc noklusējuma",
    "Allow comments by default" : "Pēc noklusējuma atļaut piebildes",
    "Comments" : "Piebildes",
    "Delete announcement" : "Dzēst paziņojumu",
    "seconds ago" : "pirms mirkļa",
    ", " : ",",
    "_%n comment_::_%n comments_" : ["%n piebilžu","%n piebilde","%n piebildes"],
    "Announce" : "Paziņot",
    "Create activities" : "Izveidot darbības",
    "Create notifications" : "Izveidot paziņojumu",
    "Allow comments" : "Atļaut piebildes",
    "Visibility" : "Redzamība",
    "Everyone" : "Visi",
    "These groups will be able to see the announcement. If no group is selected, all users can see it." : "Šīs grupas varēs redzēt paziņojumu. Ja netiks izvēlēta neviena grupa, visi lietotāji to varēs redzēt."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> announcementcenter-v7.1.0-frama.tar.gz: announcementcenter/l10n/lv.js <==
OC.L10N.register(
    "announcementcenter",
    {
    "You posted an announcement" : "Tu izliki paziņojumu",
    "{actor} posted an announcement" : "{actor} izlika paziņojumu",
    "An <strong>announcement</strong> is posted by an administrator" : "Pārvaldītājs nosūtīja <strong>paziņojumu</strong> ",
    "The subject is too long or empty" : "Temats ir par garu vai arī tukšs",
    "Announcements" : "Paziņojumi",
    "Read more" : "Lasīt vairāk",
    "{user} announced “{announcement}”" : "{user} paziņots “{announcement}”",
    "Announcement center" : "Paziņojumu centrs",
    "These groups will be able to post announcements." : "Šīs grupas varēs ievietot paziņojumus.",
    "Create activities by default" : "Izveidot darbības pēc noklusējuma",
    "Create notifications by default" : "Izveidot ziņojumus pēc noklusējuma",
    "Allow comments by default" : "Pēc noklusējuma atļaut piebildes",
    "Comments" : "Piebildes",
    "Delete announcement" : "Dzēst paziņojumu",
    "seconds ago" : "pirms mirkļa",
    ", " : ",",
    "_%n comment_::_%n comments_" : ["%n piebilžu","%n piebilde","%n piebildes"],
    "Announce" : "Paziņot",
    "Create activities" : "Izveidot darbības",
    "Create notifications" : "Izveidot paziņojumu",
    "Allow comments" : "Atļaut piebildes",
    "Visibility" : "Redzamība",
    "Everyone" : "Visi",
    "These groups will be able to see the announcement. If no group is selected, all users can see it." : "Šīs grupas varēs redzēt paziņojumu. Ja netiks izvēlēta neviena grupa, visi lietotāji to varēs redzēt."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
